.. currentmodule:: gorilla

.. _core:

Core
====

.. autosummary::
   :nosignatures:

   Settings
   Patch
   apply


----

.. autoclass:: Settings
   :members:
   :special-members: __init__

----

.. autoclass:: Patch
   :members:
   :special-members:  __init__

----

.. autofunction:: apply

----

.. autofunction:: revert
